@@ -24,8 +24,8 @@ def plot_folium(self, m: folium.Map, colormap: str = 'viridis',
     values = np.flipud(self.values[:].astype(float))
     values = (values - vmin) / (vmax - vmin)
     if x is not None:
-        latitude = x
-        longitude = y
+        latitude = y
+        longitude = x
     elif 'latitude' in self.dims and 'longitude' in self.dims:
         latitude = self.latitude
         longitude = self.longitude
